_NewAbstractModel
=================

.. currentmodule:: pykeen.models

.. autoclass:: _NewAbstractModel
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~_NewAbstractModel.regularizer_default
      ~_NewAbstractModel.regularizer_default_kwargs

   .. rubric:: Methods Summary

   .. autosummary::

      ~_NewAbstractModel.collect_regularization_term
      ~_NewAbstractModel.forward
      ~_NewAbstractModel.post_parameter_update
      ~_NewAbstractModel.score_h
      ~_NewAbstractModel.score_hrt
      ~_NewAbstractModel.score_r
      ~_NewAbstractModel.score_t

   .. rubric:: Attributes Documentation

   .. autoattribute:: regularizer_default
   .. autoattribute:: regularizer_default_kwargs

   .. rubric:: Methods Documentation

   .. automethod:: collect_regularization_term
   .. automethod:: forward
   .. automethod:: post_parameter_update
   .. automethod:: score_h
   .. automethod:: score_hrt
   .. automethod:: score_r
   .. automethod:: score_t
